pub struct RdKafkaPropertiesCommon {
pub message_max_bytes: Option<usize>,
pub receive_message_max_bytes: Option<usize>,
pub statistics_interval_ms: Option<usize>,
pub client_id: Option<String>,
pub enable_ssl_certificate_verification: Option<bool>,
pub reconnect_backoff_ms: Option<usize>,
pub reconnect_backoff_max_ms: Option<usize>,
pub socket_connection_setup_timeout_ms: Option<usize>,
pub socket_keepalive_enable: bool,
pub retry_backoff_ms: Option<usize>,
pub retry_backoff_max_ms: Option<usize>,
}Fields
message_max_bytes: Option<usize>Maximum Kafka protocol request message size. Due to differing framing overhead between
protocol versions the producer is unable to reliably enforce a strict max message limit at
produce time and may exceed the maximum size by one message in protocol ProduceRequests,
the broker will enforce the topic’s max.message.bytes limit
receive_message_max_bytes: Option<usize>Maximum Kafka protocol response message size. This serves as a safety precaution to avoid memory exhaustion in case of protocol hickups. This value must be at least fetch.max.bytes
- 512 to allow for protocol overhead; the value is adjusted automatically unless the configuration property is explicitly set.
statistics_interval_ms: Option<usize>client_id: Option<String>Client identifier
enable_ssl_certificate_verification: Option<bool>reconnect_backoff_ms: Option<usize>Initial backoff time in milliseconds before reconnecting to a broker after a connection closes.
reconnect_backoff_max_ms: Option<usize>Maximum backoff time in milliseconds before reconnecting to a broker after a connection closes.
socket_connection_setup_timeout_ms: Option<usize>Maximum time in milliseconds allowed for broker connection setup, including TCP setup and SSL/SASL handshakes.
socket_keepalive_enable: boolretry_backoff_ms: Option<usize>Initial backoff time in milliseconds before retrying a failed protocol request.
retry_backoff_max_ms: Option<usize>Maximum backoff time in milliseconds before retrying a failed protocol request.
Implementations
Sourceimpl RdKafkaPropertiesCommon
impl RdKafkaPropertiesCommon
pub(crate) fn set_client(&self, c: &mut ClientConfig)