FeatureNotEnabledSinkMarker

Trait FeatureNotEnabledSinkMarker 

pub trait FeatureNotEnabledSinkMarker: Send + 'static {
    const SINK_NAME: &'static str;
}
Implement this trait will bring a dummy impl Sink for the type which always returns an error.

Required Associated Constants

const SINK_NAME: &'static str

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors