build_pulsar_ack_channel_id

Function build_pulsar_ack_channel_id 

pub fn build_pulsar_ack_channel_id(
    source_id: SourceId,
    split_id: &SplitId,
    actor_id: ActorId,
) -> String
Build the identifier of the ACK channel for a Pulsar reader.

Multiple actors can consume the same source split in one process, so the actor ID is required to prevent one reader from replacing another reader’s channel.