sync_resolved_partitions

Function sync_resolved_partitions 

fn sync_resolved_partitions(
    resolved: &mut HashMap<i32, Option<i64>>,
    partitions: &[i32],
) -> Vec<i32>
Drops cached start offsets of partitions that are no longer present and returns the partitions whose start offset still has to be resolved.